BOOST_PP_SEQ_REMOVE

The BOOST_PP_SEQ_REMOVE macro removes an element from a seq.

#### Usage

BOOST_PP_SEQ_REMOVE(seq, i)

#### Arguments

seq
  The seq from which an element is to be removed.
i
  The zero-based position in seq of the element to be removed. Valid values range from 0 to BOOST_PP_SEQ_SIZE(seq) - 1.

#### Remarks

This macro returns seq after removing the element at index i.

#### Requirements

Header: <boost/preprocessor/seq/remove.hpp>

#### Sample Code

    #include <boost/preprocessor/seq/remove.hpp>

    #define SEQ (a)(b)(x)(c)

    BOOST_PP_SEQ_REMOVE(SEQ, 2) // expands to (a)(b)(c)

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)